@@ -6,7 +6,14 @@ import getopt
 import os
 import time
 from datetime import datetime
-from command_tool.utils.utils import logger, error_exit, config, ScanType, zip_folder, get_upload_zip_file
+from command_tool.utils.utils import (
+    logger,
+    error_exit,
+    config,
+    ScanType,
+    zip_folder,
+    get_upload_zip_file,
+)
 from command_tool.utils.user import show_user
 from command_tool.utils.login import login, create_scantist_token
 from command_tool.utils.project import show_projects, set_proj, get_proj_id
@@ -16,7 +23,11 @@ from command_tool.utils.scan import (
     scan_upload_proj,
     get_scan_id,
 )
-from command_tool.utils.report import get_report, check_scan
+from command_tool.utils.report import (
+    get_report,
+    check_scan,
+    generate_remediation_report,
+)
 from command_tool.utils.scan_result import get_scan_summary
 
 HELP_CONTENT = """
@@ -25,7 +36,7 @@ HELP_CONTENT = """
 
 - optional parameter: 
         
-        -r [csv|pdf]: download scan report
+        -r [csv|pdf|csv-remediation|pdf-remediation]: download scan report
         
         -v          : set the version of the project
         
@@ -48,19 +59,20 @@ project_id -> scan existing project.
 
 - optional parameter :
 
-        -r [csv|pdf]: download scan report
+        -r [csv|pdf|csv-remediation|pdf-remediation]: download scan report
         
         -h          : report output path. Default path is current working directory.
         
         -b          : trigger source code scan with bom-detect. Otherwise, upload file and remotely trigger build and scan.
          
+        -h          : report output path. Default path is current working directory.
 ## List user projects
 - scantist_cmd -l
 
 
 ## Download scan result
 Generate and download the most recent scan report if no $project_id given
-- scantist_cmd -r ["csv"|"pdf"]
+- scantist_cmd -r [csv|pdf|csv-remediation|pdf-remediation]
 
 - optional parameter:
 
@@ -81,6 +93,7 @@ def main():
     project_id = 0
     report_path = os.path.join(os.getcwd(), "report")
     is_bom_detect = False
+    is_generate_remediation_report = False
 
     try:
         opts, args = getopt.getopt(
@@ -118,9 +131,16 @@ def main():
         elif opt in ("-l", "--list_projects"):
             list_projects = True
         elif opt in ("-r", "--report"):
-            if arg != "csv" and arg != "pdf":
+            if (
+                arg != "csv"
+                and arg != "pdf"
+                and arg != "csv-remediation"
+                and arg != "pdf-remediation"
+            ):
                 error_exit("Scan report only accept csv or pdf format.")
-            report_format = arg
+            report_format = arg.split("-")[0]
+            if len(arg.split("-")) > 1:
+                is_generate_remediation_report = True
         elif opt in ("-h", "--report_path"):
             report_path = arg
         elif opt in ("-j", "--project_id"):
@@ -151,6 +171,7 @@ def main():
         exit(0)
 
     scan_id = 0
+    status = ""
 
     if scan_type:
         if scan_type == ScanType.BINARY:
@@ -186,7 +207,9 @@ def main():
             # Source code bom_detect Scan and upload code scan
             if is_bom_detect:
                 if not os.path.isdir(local_file):
-                    error_exit("for bom_detect source code scan, please specify a valid folder path")
+                    error_exit(
+                        "for bom_detect source code scan, please specify a valid folder path"
+                    )
 
                 scan_id = scan_sourcecode(local_file, scantist_token, baseurl)
             else:
@@ -202,7 +225,6 @@ def main():
                 )
             project_id = get_proj_id(apikey, baseurl, scan_id)
 
-        status = ""
         percentage = 0
         while status != "finished" and status != "failed":
             status, scan_percentage = check_scan(scan_id, project_id, apikey, baseurl)
@@ -214,9 +236,9 @@ def main():
 
     # project_id does not exist in source code scan
     # scan_sourcecode finish means scan finish, no need to check scan status, thus no need project id.
-    # loop = asyncio.get_event_loop()
-    if report_format:
-        
+    if (scan_type and report_format and status == "finished") or (
+        not scan_type and report_format
+    ):
         output_folder = os.path.join(
             report_path,
             os.path.splitext(os.path.basename(local_file))[0]
@@ -232,16 +254,6 @@ def main():
             os.mkdir(output_folder)
 
         if scan_type:
-            # loop.run_until_complete(
-            #     check_report(
-            #         scan_id,
-            #         apikey,
-            #         baseurl,
-            #         report_format,
-            #         output_folder,
-            #         project_id if project_id else None,
-            #     )
-            # )
             get_report(
                 scan_id,
                 apikey,
@@ -250,18 +262,13 @@ def main():
                 output_folder,
                 project_id if project_id else None,
             )
+            if is_generate_remediation_report:
+                generate_remediation_report(baseurl, apikey, scan_id, output_folder)
         else:
             # download report for the latest scan
             logger.info("Getting the most recent scan id...")
             scan_id = get_scan_id(apikey, baseurl, project_id)
-            # loop.run_until_complete(
-            #     get_report(scan_id, apikey, baseurl, report_format, output_folder)
-            # )
             logger.info(f"Generalize report for scan {scan_id}")
             get_report(scan_id, apikey, baseurl, report_format, output_folder)
 
     get_scan_summary(scan_id, apikey, baseurl)
-
-#
-# if __name__ == "__main__":
-#     main(sys.argv[1:])
\ No newline at end of file
